@@ -4,18 +4,13 @@ from .utils.aws import get_matching_s3_keys, s3resource, s3client
 from humanize import naturalsize
 import tqdm
 from .count import app as count
+from .size import app as size
 
 app = typer.Typer(add_completion=False)
 app.add_typer(count, name="count")
+app.add_typer(size, name="size")
 # TODO: enable verbose mode globally...
 
-@app.command()
-def size(bucket: str, prefix: str):
-    total_size = 0
-    for obj in s3resource.Bucket(bucket).objects.filter(Prefix=prefix):
-        total_size += obj.size
-    typer.echo(f"{naturalsize(total_size)}")
-
 @app.command()
 def download(bucket: str, prefix: str, destination: str):
     if not os.path.isdir(os.path.dirname(destination)):
